[libpng12] Removed potentially misleading warning from png_check_IHDR().
diff --git a/ANNOUNCE b/ANNOUNCE
index 3dcdb3f..3135460 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
 
-Libpng 1.2.51beta04 - January 1, 2014
+Libpng 1.2.51beta04 - January 10, 2014
 
 This is not intended to be a public release.  It will be replaced
 within a few weeks by a public version or by another test version.
@@ -57,7 +57,8 @@
     among compilers.
   Rebuilt the configure scripts with autoconf-2.69 and automake-1.14.1
 
-version 1.2.51beta04 [January 1, 2014]
+version 1.2.51beta04 [January 10, 2014]
+  Removed potentially misleading warning from png_check_IHDR().
 
 (subscription required; visit
 https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CHANGES b/CHANGES
index d34ae00..50b5e8c 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2792,7 +2792,8 @@
     among compilers.
   Rebuilt the configure scripts with autoconf-2.69 and automake-1.14.1
 
-version 1.2.51beta04 [January 1, 2014]
+version 1.2.51beta04 [January 10, 2014]
+  Removed potentially misleading warning from png_check_IHDR().
 
 Send comments/corrections/commendations to png-mng-implement at lists.sf.net
 (subscription required; visit
diff --git a/png.c b/png.c
index e594055..5160c55 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
 
 /* png.c - location for general purpose libpng functions
  *
  * Last changed in libpng 1.2.51 [January 1, 2014]
  * Copyright (c) 1998-2014 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -724,13 +724,13 @@
 #else
 #ifdef __STDC__
    return ((png_charp) PNG_STRING_NEWLINE \
-     "libpng version 1.2.51beta04 - January 1, 2014" PNG_STRING_NEWLINE \
+     "libpng version 1.2.51beta04 - January 10, 2014" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE);
 #else
-      return ((png_charp) "libpng version 1.2.51beta04 - January 1, 2014\
+      return ((png_charp) "libpng version 1.2.51beta04 - January 10, 2014\
       Copyright (c) 1998-2014 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
@@ -1009,14 +1009,6 @@
       error = 1;
    }
 
-   if ( width > (PNG_UINT_32_MAX
-                 >> 3)      /* 8-byte RGBA pixels */
-                 - 64       /* bigrowbuf hack */
-                 - 1        /* filter byte */
-                 - 7*8      /* rounding of width to multiple of 8 pixels */
-                 - 8)       /* extra max_pixel_depth pad */
-      png_warning(png_ptr, "Width is too large for libpng to process pixels");
-
    /* Check other values */
    if (bit_depth != 1 && bit_depth != 2 && bit_depth != 4 &&
        bit_depth != 8 && bit_depth != 16)
@@ -1,7 +1,7 @@
 /* png.c - location for general purpose libpng functions
  *
- * Last changed in libpng 1.2.51 [January 1, 2014]
+ * Last changed in libpng 1.2.51 [January 10, 2014]
  * Copyright (c) 1998-2014 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)